@@ -175,6 +175,11 @@ class ColorFormatter(logging.Formatter):
         # safety guard if None was provided
         if record.msg is None:
             record.msg = ""
+        else:
+            # to avoid our logger puking on receiving exception instances etc.
+            # .getMessage, used to interpolate it, would cast it to str anyways
+            # and thus not puke
+            record.msg = str(record.msg)
         if record.msg.startswith('| '):
             # If we already log smth which supposed to go without formatting, like
             # output for running a command, just return the message and be done
@@ -555,6 +560,7 @@ class LoggerHelper(object):
         #  logging.Formatter('%(asctime)-15s %(levelname)-6s %(message)s'))
         if is_interactive():
             phandler = ProgressHandler(other_handler=loghandler)
+            phandler.filters.extend(loghandler.filters)
             self.lgr.addHandler(phandler)
         else:
             loghandler.addFilter(partial(filter_noninteractive_progress,
